<html>
  <head>
    <title>pycobertura report</title>
    <meta charset="UTF-8">
    <style>
{% include 'normalize.css' %}
{% include 'skeleton.css' %}
.hit {background-color: #EAFFEA}
.miss {background-color: #FFECEC}
.container .code {margin-left: 0}
pre {line-height: 1.3}
    </style>
  </head>
  <body>
    <div class="container">
      <table class="u-full-width">
        <thead>
          <tr>
            <th>Name</th>
            <th>Stmts</th>
            <th>Miss</th>
            <th>Cover</th>
            <th>Missing</th>
          </tr>
        </thead>
        <tbody>
{%- for line in lines %}
          <tr>
            <td><a href="#{{ line.class_name }}">{{ line.class_name }}</a></td>
            <td>{{ line.total_statements }}</td>
            <td>{{ line.total_misses }}</td>
            <td>{{ line.line_rate }}</td>
            <td>{{ line.missed_lines }}</td>
          </tr>
{%- endfor %}
        </tbody>
        <tfoot>
          <tr>
            <td>{{ footer.class_name }}</td>
            <td>{{ footer.total_statements }}</td>
            <td>{{ footer.total_misses }}</td>
            <td>{{ footer.line_rate }}</td>
            <td>{{ footer.missed_lines }}</td>
          </tr>
        </tfoot>
      </table>
{%- from 'macro.source.jinja2' import render_source -%}
{%- for class_name, filename, source in sources %}
<h4 id="{{class_name}}">{{ class_name }}</h4>
{{ render_source(source) }}
{%- endfor %}
    </div>
  </body>
</html>
